==> haskell-hi-file-parser-0.1.2.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hi-file-parser
version:              0.1.2.0
visibility:           public
id:                   hi-file-parser-0.1.2.0-H09YJoopvIyA2WDcnt95yf
key:                  hi-file-parser-0.1.2.0-H09YJoopvIyA2WDcnt95yf
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Hussein Ait-Lahcen
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/hi-file-parser/blob/master/README.md>

category:             Development
abi:                  2444eb515c9b6563c77b8f2095625e4f
exposed:              True
exposed-modules:      HiFileParser
hidden-modules:       Paths_hi_file_parser
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hi-file-parser-0.1.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hi-file-parser-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hi-file-parser-0.1.2.0
hs-libraries:         HShi-file-parser-0.1.2.0-H09YJoopvIyA2WDcnt95yf
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0 mtl-2.2.2
    rio-0.1.20.0-FELbxBwqNDjG5RYUJ6S2xu
    vector-0.12.3.0-H4rWOat9KWYJKIFglDYjhy

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hi-file-parser-0.1.2.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hi-file-parser
version:              0.1.2.0
visibility:           public
id:                   hi-file-parser-0.1.2.0-GS4DWnGt5PvHJKft5MRiIF
key:                  hi-file-parser-0.1.2.0-GS4DWnGt5PvHJKft5MRiIF
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Hussein Ait-Lahcen
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/hi-file-parser/blob/master/README.md>

category:             Development
abi:                  03137f07a6d1daa8d706c33d80272607
exposed:              True
exposed-modules:      HiFileParser
hidden-modules:       Paths_hi_file_parser
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hi-file-parser-0.1.2.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hi-file-parser-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/hi-file-parser-0.1.2.0
hs-libraries:         HShi-file-parser-0.1.2.0-GS4DWnGt5PvHJKft5MRiIF
depends:
    base-4.14.2.0 binary-0.8.8.0 bytestring-0.10.12.0 mtl-2.2.2
    rio-0.1.20.0-8bEKBxdaYJr9fab9QN85HE
    vector-0.12.3.0-EcRb4NXFUGH91vV3xG3jJs

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
